summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouch.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ktouch/src/ktouch.cpp')
-rw-r--r--ktouch/src/ktouch.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/ktouch/src/ktouch.cpp b/ktouch/src/ktouch.cpp
index d9ee9d9c..278ad3fe 100644
--- a/ktouch/src/ktouch.cpp
+++ b/ktouch/src/ktouch.cpp
@@ -420,9 +420,9 @@ void KTouch::trainingStatistics() {
void KTouch::optionsPreferences() {
trainingPause();
- if ( KConfigDialog::showDialog( "settings" ) ) return;
- // KConfigDialog didn't find an instance of this dialog, so lets create it :
- KConfigDialog* dialog = new KConfigDialog( this, "settings", Prefs::self() );
+ if ( TDEConfigDialog::showDialog( "settings" ) ) return;
+ // TDEConfigDialog didn't find an instance of this dialog, so lets create it :
+ TDEConfigDialog* dialog = new TDEConfigDialog( this, "settings", Prefs::self() );
m_pageGeneral = new KTouchPrefGeneralLayout(0, "General");
dialog->addPage(m_pageGeneral, i18n("General Options"), "style");
m_pageTraining = new KTouchPrefTrainingLayout(0, "Training");
@@ -542,7 +542,7 @@ void KTouch::resizeEvent(TQResizeEvent * event) {
// Will be called when this app is restored due to session management.
// This function only stored the temperary data of the last session. All permanent
// settings should be handled by the KTouchConfiguration object.
-void KTouch::readProperties(KConfig *config) {
+void KTouch::readProperties(TDEConfig *config) {
kdDebug() << "[KTouch::readProperties] Reading session data..." << endl;
// TODO : Session management rewrite
config->setGroup("TrainingState");
@@ -575,7 +575,7 @@ void KTouch::readProperties(KConfig *config) {
// ----------------------------------------------------------------------------
// Will be called when the app should save its state for session management purposes.
-void KTouch::saveProperties(KConfig *config) {
+void KTouch::saveProperties(TDEConfig *config) {
kdDebug() << "[KTouch::saveProperties] Saving session data..." << endl;
// We are going down because of session management (most likely because of
// KDE logout). Let's save the current status so that we can restore it